@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 our @CARP_NOT = qw( MCE );
 
@@ -209,7 +209,7 @@ MCE::Candy - Sugar methods and output iterators
 
 =head1 VERSION
 
-This document describes MCE::Candy version 1.699_010
+This document describes MCE::Candy version 1.699_011
 
 =head1 DESCRIPTION
 
@@ -521,7 +521,7 @@ processing input data.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
