@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized redefine );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -171,7 +171,7 @@ sub create {
    elsif ($pid) {                                   # parent
       my $wrk_id = "$pid.$_tid";
       $self->{WRK_ID} = $wrk_id, $self->{PID} = $pid;
-      $_LIST->push($wrk_id, $self);
+      $_LIST->set($wrk_id, $self);
 
       return $self;
    }
@@ -251,6 +251,8 @@ sub exit {
 }
 
 sub finish {
+   _croak('Usage: MCE::Hobo->finish()') if ref($_[0]);
+
    if (defined $_LIST) {
       return if ($INC{'MCE/Signal.pm'} && $MCE::Signal::KILLED);
       return if ($MCE::Shared::Server::KILLED);
@@ -364,10 +366,14 @@ sub kill {
 }
 
 sub list {
+   _croak('Usage: MCE::Hobo->list()') if ref($_[0]);
+
    (defined $_LIST) ? $_LIST->vals : ();
 }
 
 sub list_joinable {
+   _croak('Usage: MCE::Hobo->list_joinable()') if ref($_[0]);
+
    if (defined $_LIST) {
       my ($mgr_id, $wrk_id) = ("$$.$_tid");
       for my $self ($_LIST->vals) {
@@ -385,6 +391,8 @@ sub list_joinable {
 }
 
 sub list_running {
+   _croak('Usage: MCE::Hobo->list_running()') if ref($_[0]);
+
    if (defined $_LIST) {
       my ($mgr_id, $wrk_id) = ("$$.$_tid");
       for my $self ($_LIST->vals) {
@@ -401,6 +409,12 @@ sub list_running {
    }
 }
 
+sub pending {
+   _croak('Usage: MCE::Hobo->pending()') if ref($_[0]);
+
+   (defined $_LIST) ? $_LIST->len : 0;
+}
+
 sub self { ref($_[0]) ? $_[0] : $_SELF; }
 sub pid  { ref($_[0]) ? $_[0]->{PID} : $_SELF->{PID}; }
 sub tid  { ref($_[0]) ? $_[0]->{WRK_ID} : $_SELF->{WRK_ID}; }
@@ -448,6 +462,7 @@ sub _exit {
 }
 
 sub _trap {
+   $SIG{ $_[0] } = sub { };
    print {*STDERR} "Signal $_[0] received in process $$.$_tid\n";
    _exit();
 }
@@ -468,7 +483,7 @@ MCE::Hobo - A threads-like parallelization module
 
 =head1 VERSION
 
-This document describes MCE::Hobo version 1.699_010
+This document describes MCE::Hobo version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -486,6 +501,7 @@ This document describes MCE::Hobo version 1.699_010
    my @hobos    = MCE::Hobo->list();
    my @running  = MCE::Hobo->list_running();
    my @joinable = MCE::Hobo->list_joinable();
+   my @count    = MCE::Hobo->pending();
 
    $_->join() for @hobos;
 
@@ -514,7 +530,7 @@ This document describes MCE::Hobo version 1.699_010
    MCE::Hobo->yield();
    MCE::Hobo->yield(0.05);
 
-   # Wantarray-aware return context
+   # Return context, wantarray aware
    my ($value1, $value2) = $hobo->join();
    my $value = $hobo->join();
 
@@ -550,7 +566,7 @@ The following is a parallel demonstration.
 
    use MCE::Hobo;
    use MCE::Shared Sereal => 1;  # Serialization via Sereal if available.
-   use MCE::Shared::Ordhash;     # Ordhash for non-shared use below.
+   use MCE::Shared::Ordhash;     # Ordered hash for non-shared use below.
 
    # usage: head -20 file.txt | perl script.pl
 
@@ -656,7 +672,7 @@ non-voided context, C<join()> will return the value(s) of the entry point
 function.
 
 The context (void, scalar or list) for the return value(s) for C<join> is
-determined at the time of joining and mostly wantarray-aware.
+determined at the time of joining and mostly C<wantarray> aware.
 
    my $hobo1 = MCE::Hobo->create( sub {
       my @results = qw(foo bar baz);
@@ -713,7 +729,7 @@ This behaves the same as C<exit(status)> when called from the main process.
 
 This class method is called automatically by C<END>, but may be called
 explicitly. Two shared objects to C<MCE::Shared> are destroyed. An error is
-emmitted via croak if there are active hobos not yet joined.
+emitted via croak if there are active hobos not yet joined.
 
    MCE::Hobo->create( 'task1', $_ ) for 1 .. 4;
 
@@ -826,6 +842,10 @@ Returns a list of all hobos that are still running.
 Returns a list of all hobos that have completed running. Thus, ready to be
 joined without blocking.
 
+=item $hobo->pending()
+
+Returns a count of all hobos not yet joined.
+
 =item MCE::Hobo->self()
 
 Class method that allows a hobo to obtain it's own I<MCE::Hobo> object.
@@ -874,7 +894,7 @@ L<Thread::Tie>
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
