@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -444,7 +444,7 @@ MCE::Map - Parallel map model similar to the native map function
 
 =head1 VERSION
 
-This document describes MCE::Map version 1.699_010
+This document describes MCE::Map version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -498,10 +498,9 @@ otherwise -1.
 
    my @m3 = mce_map_s { calc } 1, 1000000;                ## 0.270 secs
 
-Although this document is about MCE::Map, the L<MCE::Stream|MCE::Stream>
-module can write results immediately without waiting for all chunks to
-complete. This is made possible by passing the reference to an array
-(in this case @m4 and @m5).
+Although this document is about MCE::Map, the L<MCE::Stream> module can write
+results immediately without waiting for all chunks to complete. This is made
+possible by passing the reference to an array (in this case @m4 and @m5).
 
    use MCE::Stream;
 
@@ -601,7 +600,7 @@ specified, is ignored due to being used internally by the module.
 =item mce_map { code } iterator
 
 An iterator reference can by specified for input_data. Iterators are described
-under "SYNTAX for INPUT_DATA" at L<MCE::Core|MCE::Core>.
+under "SYNTAX for INPUT_DATA" at L<MCE::Core>.
 
    my @a = mce_map { $_ * 2 } make_iterator(10, 30, 2);
 
@@ -670,7 +669,7 @@ longer needed.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
