@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 use MCE::Util qw( $LF );
 
@@ -121,7 +121,7 @@ MCE::Mutex - Locking for Many-Core Engine
 
 =head1 VERSION
 
-This document describes MCE::Mutex version 1.699_010
+This document describes MCE::Mutex version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -183,7 +183,7 @@ automatically.
 =head2 $m->synchronize ( sub { ... }, @_ )
 
 Obtains a lock, runs the code block, and releases the lock after the block
-completes. Optionally, the method is wantarray aware.
+completes. Optionally, the method is C<wantarray> aware.
 
    my $value = $m->synchronize( sub {
 
@@ -194,7 +194,7 @@ completes. Optionally, the method is wantarray aware.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
