@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
@@ -63,7 +63,7 @@ sub share {
    $_count++;
 
    # blessed object, \@array, \%hash, or \$scalar
-   if ($_class) {
+   if ( $_class ) {
       _incr_count($_[0]), return $_[0] if $_[0]->can('SHARED_ID');
 
       _croak("Running MCE::Queue via MCE::Shared is not supported.\n",
@@ -73,22 +73,22 @@ sub share {
       $_params->{'class'} = $_class;
       $_item = MCE::Shared::Server::_new($_params, $_[0]);
    }
-   elsif (ref $_[0] eq 'ARRAY') {
-      if (tied(@{ $_[0] }) && tied(@{ $_[0] })->can('SHARED_ID')) {
+   elsif ( ref $_[0] eq 'ARRAY' ) {
+      if ( tied(@{ $_[0] }) && tied(@{ $_[0] })->can('SHARED_ID') ) {
          _incr_count(tied(@{ $_[0] })), return tied(@{ $_[0] });
       }
       $_item = $_lkup{ $_ra } = MCE::Shared->array($_params, @{ $_[0] });
       @{ $_[0] } = ();  tie @{ $_[0] }, 'MCE::Shared::Object', $_item;
    }
-   elsif (ref $_[0] eq 'HASH') {
-      if (tied(%{ $_[0] }) && tied(%{ $_[0] })->can('SHARED_ID')) {
+   elsif ( ref $_[0] eq 'HASH' ) {
+      if ( tied(%{ $_[0] }) && tied(%{ $_[0] })->can('SHARED_ID') ) {
          _incr_count(tied(%{ $_[0] })), return tied(%{ $_[0] });
       }
       $_item = $_lkup{ $_ra } = MCE::Shared->hash($_params, %{ $_[0] });
       %{ $_[0] } = ();  tie %{ $_[0] }, 'MCE::Shared::Object', $_item;
    }
-   elsif (ref $_[0] eq 'SCALAR' && !ref ${ $_[0] }) {
-      if (tied(${ $_[0] }) && tied(${ $_[0] })->can('SHARED_ID')) {
+   elsif ( ref $_[0] eq 'SCALAR' && !ref ${ $_[0] } ) {
+      if ( tied(${ $_[0] }) && tied(${ $_[0] })->can('SHARED_ID') ) {
          _incr_count(tied(${ $_[0] })), return tied(${ $_[0] });
       }
       $_item = $_lkup{ $_ra } = MCE::Shared->scalar($_params, ${ $_[0] });
@@ -96,11 +96,11 @@ sub share {
    }
 
    # synopsis
-   elsif (ref $_[0] eq 'REF') {
+   elsif ( ref $_[0] eq 'REF' ) {
       _croak('A "REF" type is not supported');
    }
    else {
-      if (ref $_[0] eq 'GLOB') {
+      if ( ref $_[0] eq 'GLOB' ) {
          _incr_count(tied(*{ $_[0] })), return $_[0] if (
             tied(*{ $_[0] }) && tied(*{ $_[0] })->can('SHARED_ID')
          );
@@ -124,27 +124,27 @@ sub stop  { MCE::Shared::Server::_stop()  }
 sub init  { MCE::Shared::Object::_init()  }
 
 sub condvar {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Condvar unless $INC{'MCE/Shared/Condvar.pm'};
    &share( MCE::Shared::Condvar->new(@_) );
 }
 sub minidb {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Minidb unless $INC{'MCE/Shared/Minidb.pm'};
    &share( MCE::Shared::Minidb->new(@_) );
 }
 sub queue {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Queue unless $INC{'MCE/Shared/Queue.pm'};
    &share( MCE::Shared::Queue->new(@_) );
 }
 sub scalar {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Scalar unless $INC{'MCE/Shared/Scalar.pm'};
    &share( MCE::Shared::Scalar->new(@_) );
 }
 sub sequence {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Sequence unless $INC{'MCE/Shared/Sequence.pm'};
    &share( MCE::Shared::Sequence->new(@_) );
 }
@@ -153,15 +153,15 @@ sub sequence {
 *num_sequence = \&sequence;
 
 sub array {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Array unless $INC{'MCE/Shared/Array.pm'};
 
    my $_params = ref $_[0] eq 'HASH' ? shift : {};
-   my $_item   = &share( $_params, MCE::Shared::Array->new() );
+   my $_item   = &share($_params, MCE::Shared::Array->new());
 
-   if (scalar @_) {
-      if ($_params->{_DEEPLY_}) {
-         for (my $i = 0; $i <= $#_; $i += 1) {
+   if ( scalar @_ ) {
+      if ( $_params->{_DEEPLY_} ) {
+         for ( my $i = 0; $i <= $#_; $i += 1 ) {
             &_share($_params, $_item, $_[$i]) if ref($_[$i]);
          }
       }
@@ -172,7 +172,7 @@ sub array {
 }
 
 sub handle {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Handle unless $INC{'MCE/Shared/Handle.pm'};
 
    my $_item = &share( MCE::Shared::Handle->TIEHANDLE([]) );
@@ -185,39 +185,25 @@ sub handle {
 }
 
 sub hash {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Hash unless $INC{'MCE/Shared/Hash.pm'};
 
    my $_params = ref $_[0] eq 'HASH' ? shift : {};
-   my $_item   = &share( $_params, MCE::Shared::Hash->new() );
+   my $_item   = &share($_params, MCE::Shared::Hash->new());
 
-   if (scalar @_) {
-      if ($_params->{_DEEPLY_}) {
-         for (my $i = 1; $i <= $#_; $i += 2) {
-            &_share($_params, $_item, $_[$i]) if ref($_[$i]);
-         }
-      }
-      $_item->mset(@_);
-   }
+   &_deeply_share_h($_params, $_item, @_) if @_;
 
    $_item;
 }
 
 sub ordhash {
-   shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+   shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
    require MCE::Shared::Ordhash unless $INC{'MCE/Shared/Ordhash.pm'};
 
    my $_params = ref $_[0] eq 'HASH' ? shift : {};
-   my $_item   = &share( $_params, MCE::Shared::Ordhash->new() );
+   my $_item   = &share($_params, MCE::Shared::Ordhash->new());
 
-   if (scalar @_) {
-      if ($_params->{_DEEPLY_}) {
-         for (my $i = 1; $i <= $#_; $i += 2) {
-            &_share($_params, $_item, $_[$i]) if ref($_[$i]);
-         }
-      }
-      $_item->mset(@_);
-   }
+   &_deeply_share_h($_params, $_item, @_) if @_;
 
    $_item;
 }
@@ -228,7 +214,7 @@ sub ordhash {
 ##
 ###############################################################################
 
-if ($INC{'PDL.pm'}) {
+if ( $INC{'PDL.pm'} ) {
    local $@; eval q{
 
       sub pdl_byte     { push @_, 'byte';     goto &_pdl_share }
@@ -245,7 +231,7 @@ if ($INC{'PDL.pm'}) {
       sub pdl          { push @_, 'pdl';      goto &_pdl_share }
 
       sub _pdl_share {
-         shift if (defined $_[0] && $_[0] eq 'MCE::Shared');
+         shift if ( defined $_[0] && $_[0] eq 'MCE::Shared' );
          MCE::Shared::Server::_new({ 'class' => ':construct_pdl:' }, [ @_ ]);
       }
    };
@@ -257,16 +243,17 @@ if ($INC{'PDL.pm'}) {
 ##
 ###############################################################################
 
-sub TIEARRAY { shift; MCE::Shared->array(@_) }
+sub TIEARRAY  { shift; MCE::Shared->array(@_) }
 sub TIESCALAR { shift; MCE::Shared->scalar(@_) }
 
 sub TIEHASH {
    shift;
-   if ( ref $_[0] eq 'HASH' && exists $_[0]->{'ordered'} ) {
-      shift()->{'ordered'} ? MCE::Shared->ordhash(@_) : MCE::Shared->hash(@_);
-   } else {
-      MCE::Shared->hash(@_);
-   }
+   my $_ordered = ( ref $_[0] eq 'HASH' && exists $_[0]->{'ordered'} )
+      ? shift()->{'ordered'}
+      : 0;
+   ( $_ordered )
+      ? MCE::Shared->ordhash(@_)
+      : MCE::Shared->hash(@_);
 }
 
 sub TIEHANDLE {
@@ -278,7 +265,7 @@ sub TIEHANDLE {
 
 sub _croak {
    $_count = 0, %_lkup = ();
-   if (defined $MCE::VERSION) {
+   if ( defined $MCE::VERSION ) {
       goto &MCE::_croak;
    } else {
       require MCE::Shared::Base unless $INC{'MCE/Shared/Base.pm'};
@@ -286,6 +273,17 @@ sub _croak {
    }
 }
 
+sub _deeply_share_h {
+   my ( $_params, $_item ) = ( shift, shift );
+   if ( $_params->{_DEEPLY_} ) {
+      for ( my $i = 1; $i <= $#_; $i += 2 ) {
+         &_share($_params, $_item, $_[$i]) if ref($_[$i]);
+      }
+   }
+   $_item->mset(@_);
+   return;
+}
+
 sub _incr_count {
    # increments counter for safety during destroy
    MCE::Shared::Server::_incr_count($_[0]->SHARED_ID);
@@ -314,35 +312,36 @@ MCE::Shared - MCE extension for sharing data between workers
 
 =head1 VERSION
 
-This document describes MCE::Shared version 1.699_010
+This document describes MCE::Shared version 1.699_011
 
 =head1 SYNOPSIS
 
    # OO construction
 
-   use MCE::Shared Sereal => 1;
+   use MCE::Shared;
 
    my $ar = MCE::Shared->array( @list );
    my $cv = MCE::Shared->condvar( 0 );
    my $fh = MCE::Shared->handle( '>>', \*STDOUT );
    my $ha = MCE::Shared->hash( @pairs );
-   my $db = MCE::Shared->minidb();
    my $oh = MCE::Shared->ordhash( @pairs );
+   my $db = MCE::Shared->minidb();
    my $qu = MCE::Shared->queue( await => 1, fast => 0 );
    my $va = MCE::Shared->scalar( $value );
-   my $nu = MCE::Shared->sequence( $begin, $end, $step, $fmt );
+   my $se = MCE::Shared->sequence( $begin, $end, $step, $fmt );
    my $ob = MCE::Shared->share( $blessed_object );
 
    # Tie construction
 
-   use MCE::Flow;
-   use MCE::Shared Sereal => 1;
    use feature 'say';
 
+   use MCE::Flow;
+   use MCE::Shared;
+
    tie my $var, 'MCE::Shared', 'initial value';
    tie my @ary, 'MCE::Shared', qw( a list of values );
-   tie my %has, 'MCE::Shared', ( key1 => 'value', key2 => 'value' );
-   tie my %oha, 'MCE::Shared', { ordered => 1 }, ( key1 => 'value' );
+   tie my %ha,  'MCE::Shared', ( key1 => 'value', key2 => 'value' );
+   tie my %oh,  'MCE::Shared', { ordered => 1 }, ( key1 => 'value' );
 
    tie my $cnt, 'MCE::Shared', 0;
    tie my @foo, 'MCE::Shared';
@@ -354,8 +353,8 @@ This document describes MCE::Shared version 1.699_010
       max_workers => 4
    },
    sub {
-      my ($mce) = @_;
-      my ($pid, $wid) = (MCE->pid, MCE->wid);
+      my ( $mce ) = @_;
+      my ( $pid, $wid ) = ( MCE->pid, MCE->wid );
 
       ## Locking is required when multiple workers update the same element.
       ## This requires 2 trips to the manager process (fetch and store).
@@ -376,7 +375,7 @@ This document describes MCE::Shared version 1.699_010
    say " array : $_" for (@foo);
    say "  hash : $_ => $bar{$_}" for (sort keys %bar);
 
-   -- Output
+   # Output
 
    scalar : 4
     array : 37847
@@ -396,9 +395,9 @@ C<MCE::Shared> enables extra functionality on systems with C<IO::FDPass>.
 Without it, MCE::Shared is unable to send file descriptors to the
 shared-manager process for C<queue>, C<condvar>, and possibly C<handle>.
 
-As of this writing, the L<IO::FDPass|IO::FDPass> module is not a requirement
-for running MCE::Shared nor is the check made during installation. The reason
-is that C<IO::FDPass> is not possible on Cygwin and not sure about AIX.
+As of this writing, the L<IO::FDPass> module is not a requirement for running
+C<MCE::Shared> nor is the check made during installation. The reason is that
+C<IO::FDPass> is not possible on Cygwin and not sure on AIX.
 
 The following is a suggestion for systems without C<IO::FDPass>.
 This restriction applies to C<queue>, C<condvar>, and C<handle> only.
@@ -458,16 +457,26 @@ shared-manager process.
 =item sequence
 
 C<array>, C<condvar>, C<handle>, C<hash>, C<minidb>, C<ordhash>, C<queue>,
-C<scalar>, and C<sequence> are sugar syntax for constructing a shared object.
+C<scalar>, and C<sequence> are sugar syntax for constructing a
+shared object.
 
   # long form
 
   use MCE::Shared;
+
   use MCE::Shared::Array;
   use MCE::Shared::Hash;
+  use MCE::Shared::OrdHash;
+  use MCE::Shared::Minidb;
+  use MCE::Shared::Queue;
+  use MCE::Shared::Scalar;
 
   my $ar = MCE::Shared->share( MCE::Shared::Array->new() );
   my $ha = MCE::Shared->share( MCE::Shared::Hash->new() );
+  my $oh = MCE::Shared->share( MCE::Shared::Ordhash->new() );
+  my $db = MCE::Shared->share( MCE::Shared::Minidb->new() );
+  my $qu = MCE::Shared->share( MCE::Shared::Queue->new() );
+  my $va = MCE::Shared->share( MCE::Shared::Scalar->new() );
 
   # short form
 
@@ -477,11 +486,11 @@ C<scalar>, and C<sequence> are sugar syntax for constructing a shared object.
   my $cv = MCE::Shared->condvar( 0 );
   my $fh = MCE::Shared->handle( '>>', \*STDOUT );
   my $ha = MCE::Shared->hash( @pairs );
-  my $db = MCE::Shared->minidb();
   my $oh = MCE::Shared->ordhash( @pairs );
+  my $db = MCE::Shared->minidb();
   my $qu = MCE::Shared->queue( await => 1, fast => 0 );
   my $va = MCE::Shared->scalar( $value );
-  my $nu = MCE::Shared->sequence( $begin, $end, $step, $fmt );
+  my $se = MCE::Shared->sequence( $begin, $end, $step, $fmt );
 
 =item num_sequence
 
@@ -500,23 +509,23 @@ process and returns a C<MCE::Shared::Object> containing the C<SHARED_ID>.
 The object must not contain any C<GLOB>'s or C<CODE_REF>'s or the transfer
 will fail.
 
-Unlike C<threads::shared>, objects are not deeply shared. The shared object
-is accessable only through the underlying OO interface.
+Unlike with C<threads::shared>, objects are not deeply shared. The shared
+object is accessible only through the OO interface.
 
    use MCE::Shared;
    use Hash::Ordered;
 
-   my ($ho_shared, $ho_unshared);
+   my ($ho_shared, $ho_nonshared);
 
    $ho_shared = MCE::Shared->share( Hash::Ordered->new() );
 
-   $ho_shared->push( @pairs );            # OO interface only
+   $ho_shared->push( @pairs );             # OO interface only
    $ho_shared->mset( @pairs );
 
-   $ho_unshared = $ho_shared->export();   # back to unshared
-   $ho_unshared = $ho_shared->destroy();  # including destruction
+   $ho_nonshared = $ho_shared->export();   # back to non-shared
+   $ho_nonshared = $ho_shared->destroy();  # including destruction
 
-The following provide long and short forms for constructing a shared array,
+The following provides long and short forms for constructing a shared array,
 hash, or scalar object.
 
    use MCE::Shared;
@@ -640,9 +649,9 @@ shared-manager process.
 
 =item export
 
-Exports the shared object into a non-shared object. One must export when passing
-the shared object into any dump routine. Otherwise, the data C<${ SHARED_ID }>
-is all one will see.
+Exports the shared object as a non-shared object. One must export when passing
+the object into any dump routine. Otherwise, the C<shared_id value> and
+C<blessed name> is all one will see.
 
    use MCE::Shared;
    use MCE::Shared::Ordhash;
@@ -661,15 +670,17 @@ is all one will see.
       print Data::Dumper::Dumper($_[0]) . "\n";
    }
 
-   # these do the same thing
    my $oh1 = MCE::Shared->share( MCE::Shared::Ordhash->new() );
-   my $oh2 = MCE::Shared->ordhash();
+   my $oh2 = MCE::Shared->ordhash();  # same thing
 
-   _dump($oh1);  # ${ 1 }  # SHARED_ID value
-   _dump($oh2);  # ${ 2 }
+   _dump($oh1);
+      # bless( [ 1, 'MCE::Shared::Ordhash' ], 'MCE::Shared::Object' )
 
-   _dump($oh1->export());  # actual structure and content
-   _dump($oh2->export());
+   _dump($oh2);
+      # bless( [ 2, 'MCE::Shared::Ordhash' ], 'MCE::Shared::Object' )
+
+   _dump( $oh1->export );  # dumps object structure and content
+   _dump( $oh2->export );
 
 C<export> can optionally take a list of indices/keys for what to export.
 This applies to shared array, hash, and ordhash.
@@ -685,7 +696,7 @@ This applies to shared array, hash, and ordhash.
 
    _dump($h2);
 
-   __END__
+   # Output
 
    $VAR1 = bless( {
      'I' => 'Heard',
@@ -722,7 +733,7 @@ Resets the parallel iterator for C<MCE::Shared::Minidb> Lists (HoA).
 
 =item rewind ( "query string" )
 
-Resets the parallel iterator for C<Array or (Ord)Hash>.
+Resets the parallel iterator for C<Array, Hash, and Ordhash>.
 
 =item rewind
 
@@ -732,18 +743,18 @@ C<rewind> and C<next> enable parallel iteration between workers for shared
 array, hash, minidb, ordhash, and sequence. Calling C<rewind> without an
 argument rewinds the iterator.
 
-The syntax for C<query string> is described in respective class module.
+The syntax for C<query string> is described in each respective class module.
 For sequence, the construction for C<rewind> is the same as C<new>.
 
-L<MCE::Shared::Array|MCE::Shared::Array>
+L<MCE::Shared::Array>
 
-L<MCE::Shared::Hash|MCE::Shared::Hash>
+L<MCE::Shared::Hash>
 
-L<MCE::Shared::Minidb|MCE::Shared::Minidb>
+L<MCE::Shared::Ordhash>
 
-L<MCE::Shared::Ordhash|MCE::Shared::Ordhash>
+L<MCE::Shared::Minidb>
 
-L<MCE::Shared::Sequence|MCE::Shared::Sequence>
+L<MCE::Shared::Sequence>
 
 Below is a demonstration for iterating through a shared list between workers.
 
@@ -766,7 +777,7 @@ Below is a demonstration for iterating through a shared list between workers.
 
    $_->join() for MCE::Hobo->list();
 
-   -- Output
+   # Output
 
    1: a
    2: b
@@ -780,7 +791,7 @@ Below is a demonstration for iterating through a shared list between workers.
    2: j
 
 There are two forms for iterating through a shared hash or ordhash object.
-The C<next> method is wantarray-aware providing key and value in list
+The C<next> method is C<wantarray> aware providing key and value in list
 context and value in scalar context.
 
    use MCE::Hobo;
@@ -814,11 +825,10 @@ context and value in scalar context.
    MCE::Hobo->new(\&iter2, $_) for 1 .. 3;
    $_->join() for MCE::Hobo->list();
 
-Although the shared-manager process iterates orderly, there is no guarantee for
-the amount of time required by workers. Basically, do not expect for output to
-be ordered.
+Although the shared-manager process iterates items orderly, some workers may
+require more time than others. Therefore, output order is not guaranteed.
 
-   -- Output
+   # Output
 
    1: key_a => val_a
    2: key_b => val_b
@@ -860,12 +870,105 @@ recursively.
    my $v2 = $h2->get('key')->get(3)->get('foo');  # baz
    my $v3 = $h2->{key}[3]{foo};                   # baz
 
+The following is a demonstration for a tied-hash shared variable. Before
+venturing into the actual code, notice the dump function making a call to
+C<export> explicitly for objects of type C<MCE::Shared::Object>. This is
+necessary in order to retrieve the data residing under the shared-manager
+process.
+
+   sub _dump {
+      require Data::Dumper unless $INC{'Data/Dumper.pm'};
+      no warnings 'once';
+
+      local $Data::Dumper::Varname  = 'VAR';
+      local $Data::Dumper::Deepcopy = 1;
+      local $Data::Dumper::Indent   = 1;
+      local $Data::Dumper::Purity   = 1;
+      local $Data::Dumper::Sortkeys = 0;
+      local $Data::Dumper::Terse    = 0;
+
+      ( ref $_[0] eq 'MCE::Shared::Object' )
+         ? print Data::Dumper::Dumper( $_[0]->export ) . "\n"
+         : print Data::Dumper::Dumper( $_[0] ) . "\n";
+   }
+
+   use MCE::Shared;
+
+   tie my %abc, 'MCE::Shared';
+
+   my @parents = qw( a b c );
+   my @children = qw( 1 2 3 4 );
+
+   for my $parent ( @parents ) {
+      for my $child ( @children ) {
+         $abc{ $parent }{ $child } = 1;
+      }
+   }
+
+   _dump( tied( %abc ) );
+
+   # Output
+
+   $VAR1 = bless( {
+     'c' => bless( {
+       '1' => '1',
+       '4' => '1',
+       '3' => '1',
+       '2' => '1'
+     }, 'MCE::Shared::Hash' ),
+     'a' => bless( {
+       '1' => '1',
+       '4' => '1',
+       '3' => '1',
+       '2' => '1'
+     }, 'MCE::Shared::Hash' ),
+     'b' => bless( {
+       '1' => '1',
+       '4' => '1',
+       '3' => '1',
+       '2' => '1'
+     }, 'MCE::Shared::Hash' )
+   }, 'MCE::Shared::Hash' );
+
+Dereferencing provides hash-like behavior for C<hash> and C<ordhash>.
+Also, array-like behavior is possible for C<array> not shown below.
+
+   use MCE::Shared;
+
+   my $abc = MCE::Shared->hash;
+
+   my @parents = qw( a b c );
+   my @children = qw( 1 2 3 4 );
+
+   for my $parent ( @parents ) {
+      for my $child ( @children ) {
+         $abc->{ $parent }{ $child } = 1;
+      }
+   }
+
+   _dump( $abc );
+
 Each level in a deeply structure requires a separate trip to the shared-manager
-processs. There is a faster way if the app calls for just C<HoH> and/or C<HoA>.
+process. There is a faster way if the app calls for just C<HoH> and/or C<HoA>.
 The included C<MCE::Shared::Minidb> module provides optimized methods for
 working with C<HoH> and C<HoA> structures.
 
-See L<MCE::Shared::Minidb|MCE::Shared::Minidb>.
+   use MCE::Shared;
+
+   my $abc = MCE::Shared->minidb;
+
+   my @parents = qw( a b c );
+   my @children = qw( 1 2 3 4 );
+
+   for my $parent ( @parents ) {
+      for my $child ( @children ) {
+         $abc->hset( $parent, $child, 1 );
+      }
+   }
+
+   _dump( $abc );
+
+For further reading, see L<MCE::Shared::Minidb>.
 
 =back
 
@@ -900,7 +1003,7 @@ The optional ID (an integer) is modded in a round-robin fashion.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>
+L<MCE|MCE>, L<MCE::Core>
 
 =head1 AUTHOR
 
