@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
@@ -24,8 +24,6 @@ use overload (
    fallback => 1
 );
 
-no overloading;
-
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Based on Tie::StdArray from Tie::Array.
@@ -49,12 +47,12 @@ sub FETCH     { $_[0]->[ $_[1] ] }
 sub DELETE    { delete $_[0]->[ $_[1] ] }
 sub EXISTS    { exists $_[0]->[ $_[1] ] }
 sub CLEAR     { @{ $_[0] } = () }
-sub POP       { pop(@{ $_[0] }) }
-sub PUSH      { my $o = shift; push(@$o, @_) }
-sub SHIFT     { shift(@{ $_[0] }) }
-sub UNSHIFT   { my $o = shift; unshift(@$o, @_) }
+sub POP       { pop @{ $_[0] } }
+sub PUSH      { my $ob = shift; push @{ $ob }, @_ }
+sub SHIFT     { shift @{ $_[0] } }
+sub UNSHIFT   { my $ob = shift; unshift @{ $ob }, @_ }
 
-# SPLICE ( offset, length [, list ] )
+# SPLICE ( offset [, length [, list ] ] )
 
 sub SPLICE {
    my $ob  = shift;
@@ -62,7 +60,8 @@ sub SPLICE {
    my $off = @_ ? shift : 0;
    $off   += $sz if $off < 0;
    my $len = @_ ? shift : $sz-$off;
-   return splice(@$ob, $off, $len, @_);
+
+   splice @{ $ob }, $off, $len, @_;
 }
 
 ###############################################################################
@@ -71,22 +70,6 @@ sub SPLICE {
 ##
 ###############################################################################
 
-#  Query string:
-#
-#  Several methods receive a query string argument. The string is quoteless.
-#  Basically, any quotes inside the string will be treated literally.
-#
-#  Search capability { =~ !~ eq ne lt le gt ge == != < <= > >= }
-#
-#  "key =~ /pattern/i :AND val =~ /pattern/i"
-#  "key =~ /pattern/i :AND val eq foo bar"     # val eq foo bar
-#  "val eq foo baz :OR key !~ /pattern/i"
-#
-#     key means to match against indices in the array
-#     likewise, val means to match against values
-#
-#  :AND(s) and :OR(s) mixed together is not supported
-
 # _find ( { getkeys => 1 }, "query string" )
 # _find ( { getvals => 1 }, "query string" )
 # _find ( "query string" ) # pairs
@@ -105,17 +88,7 @@ sub _find {
 sub clone {
    my $self = shift;
    my $params = ref($_[0]) eq 'HASH' ? shift : {};
-   my ( @data, $key );
-
-   if ( @_ ) {
-      while ( @_ ) {
-         $key = shift;
-         push @data, $self->[ $key ];
-      }
-   }
-   else {
-      @data = @{ $self };
-   }
+   my @data = ( @_ ) ? @{ $self }[ @_ ] : @{ $self };
 
    $self->clear() if $params->{'flush'};
 
@@ -136,7 +109,7 @@ sub flush {
 sub iterator {
    my ( $self, @keys ) = @_;
 
-   if ( !scalar @keys ) {
+   if ( ! @keys ) {
       @keys = ( 0 .. $#{ $self } );
    }
    elsif ( @keys == 1 && $keys[0] =~ /^(?:key|val)[ ]+\S\S?[ ]+\S/ ) {
@@ -145,7 +118,7 @@ sub iterator {
 
    return sub {
       return unless @keys;
-      my $key = shift(@keys);
+      my $key = shift @keys;
       return ( $key => $self->[ $key ] );
    };
 }
@@ -187,7 +160,7 @@ sub pairs {
             : map { $_ => $self->[ $_ ] } 0 .. $#{ $self };
       }
       else {
-         ( scalar @{ $self } ) << 1;
+         scalar @{ $self };
       }
    }
 }
@@ -227,7 +200,7 @@ sub mdel {
 
    while ( @_ ) {
       $key = shift;
-      $cnt++, delete($self->[ $key ]) if exists($self->[ $key ]);
+      $cnt++, delete($self->[ $key ]) if ( exists $self->[ $key ] );
    }
 
    $cnt;
@@ -241,7 +214,7 @@ sub mexists {
 
    while ( @_ ) {
       $key = shift;
-      return '' if ( !exists $self->[ $key ] );
+      return '' unless ( exists $self->[ $key ] );
    }
 
    1;
@@ -300,8 +273,8 @@ sub sort {
    my ( $alpha, $desc ) = ( 0, 0 );
 
    if ( length $request ) {
-      $alpha = 1 if $request =~ /\balpha\b/i;
-      $desc  = 1 if $request =~ /\bdesc\b/i;
+      $alpha = 1 if ( $request =~ /\balpha\b/i );
+      $desc  = 1 if ( $request =~ /\bdesc\b/i );
    }
 
    # Return sorted values, leaving the data intact.
@@ -344,8 +317,7 @@ sub _reorder {
 # append ( index, string )
 
 sub append {
-   $_[0]->[ $_[1] ] .= $_[2] || '';
-   length $_[0]->[ $_[1] ];
+   length( $_[0]->[ $_[1] ] .= $_[2] // '' );
 }
 
 # decr    ( index )
@@ -359,19 +331,24 @@ sub decr    { --$_[0]->[ $_[1] ]               }
 sub decrby  {   $_[0]->[ $_[1] ] -= $_[2] || 0 }
 sub incr    { ++$_[0]->[ $_[1] ]               }
 sub incrby  {   $_[0]->[ $_[1] ] += $_[2] || 0 }
-sub getdecr {   $_[0]->[ $_[1] ]--        || 0 }
-sub getincr {   $_[0]->[ $_[1] ]++        || 0 }
+sub getdecr {   $_[0]->[ $_[1] ]--        // 0 }
+sub getincr {   $_[0]->[ $_[1] ]++        // 0 }
 
 # getset ( index, value )
 
-sub getset { my $old = $_[0]->[ $_[1] ]; $_[0]->[ $_[1] ] = $_[2]; $old }
+sub getset {
+   my $old = $_[0]->[ $_[1] ];
+   $_[0]->[ $_[1] ] = $_[2];
+
+   $old;
+}
 
 # len ( index )
 # len ( )
 
 sub len {
    ( defined $_[1] )
-      ? length $_[0]->[ $_[1] ] || 0
+      ? length $_[0]->[ $_[1] ]
       : scalar @{ $_[0] };
 }
 
@@ -411,7 +388,7 @@ MCE::Shared::Array - Array helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Array version 1.699_010
+This document describes MCE::Shared::Array version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -459,8 +436,8 @@ This document describes MCE::Shared::Array version 1.699_010
    @vals  = $ar->sort( "alpha desc" );        # $b cmp $a
 
    # search capability key/val { =~ !~ eq ne lt le gt ge == != < <= > >= }
-   # query string is quoteless, otherwise quote(s) are treated literally
    # key/val means to match against actual key/val respectively
+   # do not add quotes inside the string unless intended literally
    # do not mix :AND(s) and :OR(s) together
 
    @keys  = $ar->keys( "key =~ /$pattern/i" );
@@ -495,28 +472,38 @@ This document describes MCE::Shared::Array version 1.699_010
 
 =head1 DESCRIPTION
 
-An array helper class for use with L<MCE::Shared|MCE::Shared>.
+An array helper class for use with L<MCE::Shared>.
 
-=head1 QUERY STRING
+=head1 SYNTAX for QUERY STRING
 
-Several methods in C<MCE::Shared::Array> receive a query string argument.
-The string is quoteless. Basically, any quotes inside the string will be
-treated literally.
+Several methods in C<MCE::Shared::Array> take a query string for an argument.
+The format of the string is quoteless. Therefore, any quotes inside the string
+is treated literally.
 
-   Search capability { =~ !~ eq ne lt le gt ge == != < <= > >= }
+   o Basic demonstration: @keys = $ar->keys( "val =~ /pattern/" );
+   o Supported operators: =~ !~ eq ne lt le gt ge == != < <= > >=
+   o Multiple expressions are delimited by :AND or :OR.
 
-   "key =~ /pattern/i :AND val =~ /pattern/i"
-   "key =~ /pattern/i :AND val eq foo bar"     # val eq foo bar
-   "val eq foo baz :OR key !~ /pattern/i"
+     "key =~ /pattern/i :AND val =~ /pattern/i"
+     "key =~ /pattern/i :AND val eq foo bar"     # val eq "foo bar"
+     "val eq foo baz :OR key !~ /pattern/i"
 
-      key means to match against indices in the array
-      likewise, val means to match against values
+     * key matches on indices in the array
+     * val matches on values
 
-   :AND(s) and :OR(s) mixed together is not supported
+=over 3
+
+=item * The modifiers C<:AND> and C<:OR> may be mixed case. e.g. C<:And>
+
+=item * Mixing C<:AND> and C<:OR> in the query is not supported.
+
+=back
 
 =head1 API DOCUMENTATION
 
-To be completed before the final 1.700 release.
+This module may involve TIE when accessing the object via array-like behavior.
+Only shared instances are impacted if doing so. Although likely fast enough for
+many use cases, use the OO interface if better performance is desired.
 
 =over 3
 
@@ -538,91 +525,281 @@ Constructs a new object, with an optional list of values.
 
 =item clear
 
+Removes all elements from the array.
+
+   $ar->clear;
+   @{$ar} = ();
+
 =item clone ( index [, index, ... ] )
 
-=item clone
+Creates a shallow copy, a C<MCE::Shared::Array> object. It returns an exact
+copy if no arguments are given. Otherwise, the object includes only the given
+indices in the same order. Indices that do not exist in the array will have
+the C<undef> value.
+
+   $ar2 = $ar->clone( 0, 1 );
+   $ar2 = $ar->clone;
 
 =item delete ( index )
 
+Deletes and returns the value associated by index or C<undef> if index exceeds
+the size of the list.
+
+   $val = $ar->delete( 20 );
+   $val = delete $ar->[ 20 ];
+
 =item del
 
 C<del> is an alias for C<delete>.
 
 =item exists ( index )
 
-=item flush ( index [, index, ... ] )
+Determines if an element by its index exists in the array. The behavior is
+strongly tied to the use of delete on lists.
 
-=item flush
+   $ar->push(qw/ value0 value1 value2 value3 /);
+
+   $ar->exists( 2 );     # True
+   $ar->exists( 2, 3 );  # True
+   $ar->delete( 2 );     # value2
+
+   $ar->exists( 2 );     # False
+   $ar->exists( 2, 3 );  # False
+   $ar->exists( 3 );     # True
+
+   exists $ar->[ 3 ];
+
+=item flush ( index [, index, ... ] )
 
 Same as C<clone>. Though, clears all existing items before returning.
 
 =item get ( index )
 
+Gets the value of an element by its index or C<undef> if the index does not
+exists.
+
+   $val = $ar->get( 2 );
+   $val = $ar->[ 2 ];
+
 =item iterator ( index [, index, ... ] )
 
+Returns a code reference for iterating a list of index-value pairs stored in
+the array when no arguments are given. Otherwise, returns a code reference for
+iterating the given indices in the same order. Indices that do not exist will
+have the C<undef> value.
+
+The list of indices to return is set when the closure is constructed. New
+indices added later are not included. Subsequently, the C<undef> value is
+returned for deleted indices.
+
+   $iter = $ar->iterator;
+   $iter = $ar->iterator( 0, 1 );
+
+   while ( my ( $index, $val ) = $iter->() ) {
+      ...
+   }
+
 =item iterator ( "query string" )
 
-=item iterator
+Returns a code reference for iterating a list of index-value pairs that match
+the given criteria. It returns an empty list if the search found nothing.
+The syntax for the C<query string> is described above.
+
+   $iter = $ar->iterator( "val eq some value" );
+   $iter = $ar->iterator( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   $iter = $ar->iterator( "val eq sun :OR val eq moon :OR val eq foo" );
+   $iter = $ar->iterator( "key =~ /$pattern/" );
+
+   while ( my ( $index, $val ) = $iter->() ) {
+      ...
+   }
 
 =item keys ( index [, index, ... ] )
 
+Returns all indices in the array when no arguments are given. Otherwise,
+returns the given indices in the same order. Indices that do not exist will
+have the C<undef> value. In scalar context, returns the size of the array.
+
+   @keys = $ar->keys;
+   @keys = $ar->keys( 0, 1 );
+   $len  = $ar->keys;
+
 =item keys ( "query string" )
 
-=item keys
+Returns only indices that match the given criteria. It returns an empty list
+if the search found nothing. The syntax for the C<query string> is described
+above. In scalar context, returns the size of the resulting list.
+
+   @keys = $ar->keys( "val eq some value" );
+   @keys = $ar->keys( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   @keys = $ar->keys( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len  = $ar->keys( "key =~ /$pattern/" );
 
 =item len ( index )
 
-Returns the length of the value stored at index.
-
-   $len = $ar->len( 0 );
-
-=item len
-
-Returns the length of the list.
+Returns the size of the array when no arguments are given. For the given
+index, returns the length of the value stored at index or the C<undef> value
+if the index does not exists.
 
    $len = $ar->len;
+   $len = $ar->len( 0 );
+   $len = length $ar->[ 0 ];
 
 =item mdel ( index [, index, ... ] )
 
+Deletes one or more elements by its index and returns the number of indices
+deleted. A given index which does not exist in the list is not counted.
+
+   $cnt = $ar->mdel( 0, 1 );
+
 =item mexists ( index [, index, ... ] )
 
+Returns a true value if all given indices exists in the list. A false value is
+returned otherwise.
+
+   if ( $ar->mexists( 0, 1 ) ) { ... }
+
 =item mget ( index [, index, ... ] )
 
+Gets multiple values from the list by its index. It returns C<undef> for indices
+which do not exists in the list.
+
+   ( $val1, $val2 ) = $ar->mget( 0, 1 );
+
 =item mset ( index, value [, index, value, ... ] )
 
+Sets multiple index-value pairs in the list and returns the length of the list.
+
+   $len = $ar->mset( 0 => "val1", 1 => "val2" );
+
 =item merge
 
 C<merge> is an alias for C<mset>.
 
-=item pairs ( index [, index, ... ] )
-
 =item pairs ( "query string" )
 
-=item pairs
+Returns index-value pairs in the array when no arguments are given. Otherwise,
+returns index-value pairs for the given indices in the same order. Indices that
+do not exist will have the C<undef> value. In scalar context, returns the size
+of the array.
+
+   @pairs = $ar->pairs;
+   @pairs = $ar->pairs( 0, 1 );
+   $len   = $ar->pairs;
+
+=item pairs ( index [, index, ... ] )
+
+Returns only index-value pairs that match the given criteria. It returns an
+empty list if the search found nothing. The syntax for the C<query string> is
+described above. In scalar context, returns the size of the resulting list.
+
+   @pairs = $ar->pairs( "val eq some value" );
+   @pairs = $ar->pairs( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   @pairs = $ar->pairs( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len   = $ar->pairs( "key =~ /$pattern/" );
 
 =item pop
 
-=item push ( list )
+Removes and returns the last value of the list. If there are no elements in the
+list, returns the undefined value.
+
+   $val = $ar->pop;
+
+=item push ( value [, value, ... ] )
+
+Appends one or multiple values to the tail of the list and returns the new
+length.
+
+   $len = $ar->push( "val1", "val2" );
 
 =item set ( index, value )
 
+Sets the value of the given array index and returns its new value.
+
+   $val = $ar->set( 2, "value" );
+   $val = $ar->[ 2 ] = "value";
+
 =item shift
 
+Removes and returns the first value of the list. If there are no elements in the
+list, returns the undefined value.
+
+   $val = $ar->shift;
+
 =item range ( start, stop )
 
+Returns the specified elements of the list. The offsets C<start> and C<stop>
+can also be negative numbers indicating offsets starting at the end of the
+list.
+
+An empty list is returned if C<start> is larger than the end of the list.
+C<stop> is set to the last index of the list if larger than the actual end
+of the list.
+
+   @list = $ar->range( 20, 29 );
+   @list = $ar->range( -4, -1 );
+
 =item sort ( "BY val [ ASC | DESC ] [ ALPHA ]" )
 
-=item sort ( "[ ASC | DESC ] [ ALPHA ]" )
+Returns sorted values in list context, leaving the elements intact. In void
+context, sorts the list in-place. By default, sorting is numeric when no
+arguments are given. The C<BY val> modifier is optional and may be omitted.
 
-=item splice ( offset, length, list )
+   @vals = $ar->sort( "BY val" );
 
-=item unshift ( list )
+   $ar->sort();
+
+If the list contains string values and you want to sort them lexicographically,
+specify the C<ALPHA> modifier.
+
+   @vals = $ar->sort( "BY val ALPHA" );
+
+   $ar->sort( "ALPHA" );
+
+The default is C<ASC> for sorting the list from small to large. In order to
+sort the list from large to small, specify the C<DESC> modifier.
+
+   @vals = $ar->sort( "DESC ALPHA" );
+
+   $ar->sort( "DESC ALPHA" );
+
+=item splice ( offset [, length [, list ] ] )
+
+Removes the elements designated by C<offset> and C<length> from the array, and
+replaces them with the elements of C<list>, if any. The behavior is similar to
+the Perl C<splice> function.
+
+   @items = $ar->splice( 20, 2, @list );
+   @items = $ar->splice( 20, 2 );
+   @items = $ar->splice( 20 );
+
+=item unshift ( value [, value, ... ] )
+
+Prepends one or multiple values to the head of the list and returns the new
+length.
+
+   $len = $ar->unshift( "val1", "val2" );
 
 =item values ( index [, index, ... ] )
 
+Returns all values in the array when no arguments are given. Otherwise, returns
+values for the given indices in the same order. Indices that do not exist will
+have the C<undef> value. In scalar context, returns the size of the array.
+
+   @vals = $ar->values;
+   @vals = $ar->values( 0, 1 );
+   $len  = $ar->values;
+
 =item values ( "query string" )
 
-=item values
+Returns only values that match the given criteria. It returns an empty list
+if the search found nothing. The syntax for the C<query string> is described
+above. In scalar context, returns the size of the resulting list.
+
+   @keys = $ar->values( "val eq some value" );
+   @keys = $ar->values( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   @keys = $ar->values( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len  = $ar->values( "key =~ /$pattern/" );
 
 =item vals
 
@@ -642,7 +819,7 @@ L<http://redis.io/commands#strings> with key representing the array index.
 
 Appends a value to a key and returns its new length.
 
-   $len = $ar->append( 0, 'foo' );
+   $len = $ar->append( 0, "foo" );
 
 =item decr ( key )
 
@@ -672,7 +849,7 @@ Increments the value of a key by one and returns its old value.
 
 Sets the value of a key and returns its old value.
 
-   $old = $ar->getset( 0, 'baz' );
+   $old = $ar->getset( 0, "baz" );
 
 =item incr ( key )
 
@@ -690,11 +867,11 @@ Increments the value of a key by the given number and returns its new value.
 
 =head1 CREDITS
 
-The implementation is inspired by L<Tie::StdArray|Tie::StdArray>.
+The implementation is inspired by L<Tie::StdArray>.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
