@@ -11,15 +11,13 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 use Scalar::Util qw( looks_like_number );
 use bytes;
 
-no overloading;
-
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Find.     ** do not remove *numeric* from no warnings above **
@@ -56,14 +54,31 @@ sub _compile {
    my ( $query ) = @_;
    my ( @f,@c,@e, $aflg );
 
-   # Search capability { =~ !~ eq ne lt le gt ge == != < <= > >= }
+   # o Several methods in MCE::Shared::{ Array, Hash, Minidb, and Ordhash }
+   #   take a query string for an argument. The format of the string is
+   #   quoteless. Therefore, any quotes inside the string is treated
+   #   literally.
    #
-   # Any quotes inside the string are treated literally
-   # :AND(s) and :OR(s) mixed together is not supported
+   # o Basic demonstration: @keys = $oh->keys( "val =~ /pattern/" );
+   # o Supported operators: =~ !~ eq ne lt le gt ge == != < <= > >=
+   # o Multiple expressions are delimited by :AND or :OR.
    #
-   # "key =~ /$pattern/i :AND field =~ /$pattern/i"
-   # "key =~ /$pattern/i :AND val eq foo bar"     # val eq 'foo bar'
-   # "val eq foo bar :OR key !~ /$pattern/i"
+   #   "key =~ /pattern/i :AND field =~ /pattern/i"
+   #   "key =~ /pattern/i :AND index =~ /pattern/i"
+   #   "key =~ /pattern/i :AND field eq foo bar"     # address eq "foo bar"
+   #   "index eq foo baz :OR key !~ /pattern/i"      # 9 eq "foo baz"
+   #
+   #   MCE::Shared::{ Array, Hash, Ordhash }
+   #   * key matches on keys in the hash or index in the array
+   #   * val matches on values
+   #
+   #   MCE::Shared::{ Minidb }
+   #   * key   matches on primary keys in the hash (H)oH or (H)oA
+   #   * field matches on HoH->{key}{field} e.g. address
+   #   * index matches on HoA->{key}[index] e.g. 9
+   #
+   # o The modifiers :AND and :OR may be mixed case. e.g. :And
+   # o Mixing :AND and :OR in the query is not supported.
 
    if ( length $query ) {
       local $@;  $aflg = ( $query =~ / :and /i );
@@ -92,7 +107,7 @@ sub _compile {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Find items in array.
+## Find items in array: called by MCE::Shared::Array.
 ##
 ###############################################################################
 
@@ -180,7 +195,7 @@ sub _find_array {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Find items in hash.
+## Find items in hash: called by MCE::Shared::{ Hash, Minidb, Ordhash }.
 ##
 ###############################################################################
 
@@ -439,15 +454,15 @@ MCE::Shared::Base - Base package for helper classes
 
 =head1 VERSION
 
-This document describes MCE::Shared::Base version 1.699_010
+This document describes MCE::Shared::Base version 1.699_011
 
 =head1 DESCRIPTION
 
-Common functions for L<MCE::Shared|MCE::Shared>. There is no public API.
+Common functions for L<MCE::Shared>. There is no public API.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
