@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 use MCE::Shared::Base;
 use MCE::Util ();
@@ -24,8 +24,6 @@ use overload (
    fallback => 1
 );
 
-no overloading;
-
 my $_has_threads = $INC{'threads.pm'} ? 1 : 0;
 my $_tid = $_has_threads ? threads->tid() : 0;
 
@@ -85,8 +83,7 @@ sub wait      { }
 # append ( string )
 
 sub append {
-   $_[0]->{_value} .= $_[1] || '';
-   length $_[0]->{_value};
+   length( $_[0]->{_value} .= $_[1] // '' );
 }
 
 # decr
@@ -100,16 +97,23 @@ sub decr    { --$_[0]->{_value}               }
 sub decrby  {   $_[0]->{_value} -= $_[1] || 0 }
 sub incr    { ++$_[0]->{_value}               }
 sub incrby  {   $_[0]->{_value} += $_[1] || 0 }
-sub getdecr {   $_[0]->{_value}--        || 0 }
-sub getincr {   $_[0]->{_value}++        || 0 }
+sub getdecr {   $_[0]->{_value}--        // 0 }
+sub getincr {   $_[0]->{_value}++        // 0 }
 
 # getset ( value )
 
-sub getset { my $old = $_[0]->{_value}; $_[0]->{_value} = $_[1]; $old }
+sub getset {
+   my $old = $_[0]->{_value};
+   $_[0]->{_value} = $_[1];
+
+   $old;
+}
 
 # len ( )
 
-sub len { length($_[0]->{_value}) || 0 }
+sub len {
+   length $_[0]->{_value};
+}
 
 1;
 
@@ -127,7 +131,7 @@ MCE::Shared::Condvar - Condvar helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Condvar version 1.699_010
+This document describes MCE::Shared::Condvar version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -162,8 +166,8 @@ This document describes MCE::Shared::Condvar version 1.699_010
 
 =head1 DESCRIPTION
 
-This helper class for L<MCE::Shared|MCE::Shared> provides a C<Scalar>, C<Mutex>,
-and primitives for conditional locking.
+This helper class for L<MCE::Shared> provides a C<Scalar>, C<Mutex>, and
+primitives for conditional locking.
 
 The following demonstrates barrier synchronization.
 
@@ -173,9 +177,9 @@ The following demonstrates barrier synchronization.
 
    my $num_workers = 8;
    my $count = MCE::Shared->condvar(0);
-   my $state = MCE::Shared->scalar('ready');
+   my $state = MCE::Shared->scalar("ready");
 
-   my $microsecs = ($^O eq 'cygwin') ? 0 : 200;
+   my $microsecs = ($^O eq "cygwin") ? 0 : 200;
 
    # The lock is released upon calling ->broadcast, ->signal, ->timedwait,
    # or ->wait. For performance reasons, the variable is *not* re-locked
@@ -183,20 +187,20 @@ The following demonstrates barrier synchronization.
    # afterwards if necessary.
 
    sub barrier_sync {
-      usleep($microsecs) until $state->get eq 'ready' or $state->get eq 'up';
+      usleep($microsecs) until $state->get eq "ready" or $state->get eq "up";
 
       $count->lock;
-      $state->set('up'), $count->incr;
+      $state->set("up"), $count->incr;
 
       if ($count->get == $num_workers) {
-         $count->decr, $state->set('down');
+         $count->decr, $state->set("down");
          $count->broadcast;
       }
       else {
-         $count->wait while $state->get eq 'up';
+         $count->wait while $state->get eq "up";
          $count->lock;
          $count->decr;
-         $state->set('ready') if $count->get == 0;
+         $state->set("ready") if $count->get == 0;
          $count->unlock;
       }
    }
@@ -255,7 +259,8 @@ Returns the value associated with the C<cv> object.
 
 =item len
 
-Returns the length of the value.
+Returns the length of the value. It returns the C<undef> value if the value
+is not defined.
 
    $len = $var->len;
 
@@ -302,7 +307,7 @@ Releases a held lock on the variable. Then, waits until another thread does a
 C<signal> or C<broadcast> for the same variable. The variable is *not* locked
 upon return.
 
-   $count->wait() while $state->get() eq 'bar';
+   $count->wait() while $state->get() eq "bar";
 
 =item timedwait ( floating_seconds )
 
@@ -313,7 +318,7 @@ C<floating_seconds>.
 A false value is returned if the timeout is reached, and a true value otherwise.
 In either case, the variable is *not* locked upon return.
 
-   $count->timedwait( 10 ) while $state->get() eq 'foo';
+   $count->timedwait( 10 ) while $state->get() eq "foo";
 
 =back
 
@@ -329,7 +334,7 @@ L<http://redis.io/commands#strings> without the key argument.
 
 Appends a value at the end of the current value and returns its new length.
 
-   $len = $cv->append( 'foo' );
+   $len = $cv->append( "foo" );
 
 =item decr
 
@@ -359,7 +364,7 @@ Increments the value by one and returns its old value.
 
 Sets the value and returns its old value.
 
-   $old = $cv->getset( 'baz' );
+   $old = $cv->getset( "baz" );
 
 =item incr
 
@@ -377,16 +382,16 @@ Increments the value by the given number and returns its new value.
 
 =head1 CREDITS
 
-The conditonal locking aspect is inspired by L<threads::shared|threads::shared>.
+The conditional locking aspect is inspired by L<threads::shared>.
 
 =head1 LIMITATION
 
-Perl must have the L<IO::FDPass|IO::FDPass> module installed for constructing
-a shared C<queue> or C<condvar> while the shared-manager process is running.
+Perl must have the L<IO::FDPass> module installed for constructing a shared
+C<queue> or C<condvar> while the shared-manager process is running.
 
 For platforms where C<IO::FDPass> is not feasible, construct C<queues> or
 C<condvars> first before other classes. The shared-manager process is delayed
-until sharing other classes or explictly starting the process.
+until sharing other classes or explicitly starting the process.
 
    use MCE::Shared;
 
@@ -397,7 +402,7 @@ until sharing other classes or explictly starting the process.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
