@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (InputOutput::ProhibitTwoArgOpen)
 
@@ -127,7 +127,7 @@ MCE::Shared::Handle - Handle helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Handle version 1.699_010
+This document describes MCE::Shared::Handle version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -178,7 +178,7 @@ This document describes MCE::Shared::Handle version 1.699_010
 
 =head1 DESCRIPTION
 
-Helper class for L<MCE::Shared|MCE::Shared>.
+Helper class for L<MCE::Shared>.
 
 =head1 API DOCUMENTATION
 
@@ -217,16 +217,16 @@ with C<reference> prior to starting the shared-manager process. Constructing a
 shared object C<{ Array, Handle, Hash, Minidb, Ordhash, Scalar, Sequence }>
 starts the manager process automatically.
 
-Perl must have the L<IO::FDPass|IO::FDPass> module installed for MCE::Shared to
-pass a C<file_descriptor> higher than 2 to the shared-manager process.
+Perl must have the L<IO::FDPass> module installed for C<MCE::Shared> to pass a
+C<file_descriptor> higher than 2 to the shared-manager process.
 
 =head1 CREDITS
 
-Implementation inspired by L<Tie::StdHandle|Tie::StdHandle>.
+Implementation inspired by L<Tie::StdHandle>.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
