@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
@@ -24,8 +24,6 @@ use overload (
    fallback => 1
 );
 
-no overloading;
-
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Based on Tie::StdHash from Tie::Hash.
@@ -54,22 +52,6 @@ sub SCALAR   { scalar keys %{ $_[0] } }
 ##
 ###############################################################################
 
-#  Query string:
-#
-#  Several methods receive a query string argument. The string is quoteless.
-#  Basically, any quotes inside the string will be treated literally.
-#
-#  Search capability { =~ !~ eq ne lt le gt ge == != < <= > >= }
-#
-#  "key =~ /pattern/i :AND val =~ /pattern/i"
-#  "key =~ /pattern/i :AND val eq foo bar"     # val eq foo bar
-#  "val eq foo baz :OR key !~ /pattern/i"
-#
-#     key means to match against keys in the hash
-#     likewise, val means to match against values
-#
-#  :AND(s) and :OR(s) mixed together is not supported
-
 # _find ( { getkeys => 1 }, "query string" )
 # _find ( { getvals => 1 }, "query string" )
 # _find ( "query string" ) # pairs
@@ -79,9 +61,7 @@ sub _find {
    my $params = ref($_[0]) eq 'HASH' ? shift : {};
    my $query  = shift;
 
-   MCE::Shared::Base::_find_hash(
-      $self, $params, $query, $self
-   );
+   MCE::Shared::Base::_find_hash( $self, $params, $query, $self );
 }
 
 # clone ( key [, key, ... ] )
@@ -90,13 +70,10 @@ sub _find {
 sub clone {
    my $self = shift;
    my $params = ref($_[0]) eq 'HASH' ? shift : {};
-   my ( %data, $key );
+   my %data;
 
    if ( @_ ) {
-      while ( @_ ) {
-         $key = shift;
-         $data{ $key } = $self->{ $key };
-      }
+      @data{ @_ } = @{ $self }{ @_ };
    }
    else {
       %data = %{ $self };
@@ -121,7 +98,7 @@ sub flush {
 sub iterator {
    my ( $self, @keys ) = @_;
 
-   if ( !scalar @keys ) {
+   if ( ! @keys ) {
       @keys = CORE::keys %{ $self };
    }
    elsif ( @keys == 1 && $keys[0] =~ /^(?:key|val)[ ]+\S\S?[ ]+\S/ ) {
@@ -130,7 +107,7 @@ sub iterator {
 
    return sub {
       return unless @keys;
-      my $key = shift(@keys);
+      my $key = shift @keys;
       return ( $key => $self->{ $key } );
    };
 }
@@ -172,7 +149,7 @@ sub pairs {
             : %{ $self };
       }
       else {
-         ( scalar CORE::keys %{ $self } ) << 1;
+         scalar CORE::keys %{ $self };
       }
    }
 }
@@ -212,7 +189,7 @@ sub mdel {
 
    while ( @_ ) {
       $key = shift;
-      $cnt++, delete($self->{ $key }) if exists($self->{ $key });
+      $cnt++, delete($self->{ $key }) if ( exists $self->{ $key } );
    }
 
    $cnt;
@@ -226,7 +203,7 @@ sub mexists {
 
    while ( @_ ) {
       $key = shift;
-      return '' if ( !exists $self->{ $key } );
+      return '' unless ( exists $self->{ $key } );
    }
 
    1;
@@ -261,8 +238,7 @@ sub mset {
 # append ( key, string )
 
 sub append {
-   $_[0]->{ $_[1] } .= $_[2] || '';
-   length $_[0]->{ $_[1] };
+   length( $_[0]->{ $_[1] } .= $_[2] // '' );
 }
 
 # decr    ( key )
@@ -276,19 +252,24 @@ sub decr    { --$_[0]->{ $_[1] }               }
 sub decrby  {   $_[0]->{ $_[1] } -= $_[2] || 0 }
 sub incr    { ++$_[0]->{ $_[1] }               }
 sub incrby  {   $_[0]->{ $_[1] } += $_[2] || 0 }
-sub getdecr {   $_[0]->{ $_[1] }--        || 0 }
-sub getincr {   $_[0]->{ $_[1] }++        || 0 }
+sub getdecr {   $_[0]->{ $_[1] }--        // 0 }
+sub getincr {   $_[0]->{ $_[1] }++        // 0 }
 
 # getset ( key, value )
 
-sub getset { my $old = $_[0]->{ $_[1] }; $_[0]->{ $_[1] } = $_[2]; $old }
+sub getset {
+   my $old = $_[0]->{ $_[1] };
+   $_[0]->{ $_[1] } = $_[2];
+
+   $old;
+}
 
 # len ( key )
 # len ( )
 
 sub len {
    ( defined $_[1] )
-      ? length $_[0]->{ $_[1] } || 0
+      ? length $_[0]->{ $_[1] }
       : scalar CORE::keys %{ $_[0] };
 }
 
@@ -323,7 +304,7 @@ MCE::Shared::Hash - Hash helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Hash version 1.699_010
+This document describes MCE::Shared::Hash version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -359,8 +340,8 @@ This document describes MCE::Shared::Hash version 1.699_010
    $len   = $ha->mset( $key/$val pairs );     # merge is an alias for mset
 
    # search capability key/val { =~ !~ eq ne lt le gt ge == != < <= > >= }
-   # query string is quoteless, otherwise quote(s) are treated literally
    # key/val means to match against actual key/val respectively
+   # do not add quotes inside the string unless intended literally
    # do not mix :AND(s) and :OR(s) together
 
    @keys  = $ha->keys( "key =~ /$pattern/i" );
@@ -395,28 +376,38 @@ This document describes MCE::Shared::Hash version 1.699_010
 
 =head1 DESCRIPTION
 
-A hash helper class for use with L<MCE::Shared|MCE::Shared>.
+A hash helper class for use with L<MCE::Shared>.
 
-=head1 QUERY STRING
+=head1 SYNTAX for QUERY STRING
 
-Several methods in C<MCE::Shared::Hash> receive a query string argument.
-The string is quoteless. Basically, any quotes inside the string will be
-treated literally.
+Several methods in C<MCE::Shared::Hash> take a query string for an argument.
+The format of the string is quoteless. Therefore, any quotes inside the string
+is treated literally.
 
-   Search capability: =~ !~ eq ne lt le gt ge == != < <= > >=
+   o Basic demonstration: @keys = $ha->keys( "val =~ /pattern/" );
+   o Supported operators: =~ !~ eq ne lt le gt ge == != < <= > >=
+   o Multiple expressions are delimited by :AND or :OR.
 
-   "key =~ /pattern/i :AND val =~ /pattern/i"
-   "key =~ /pattern/i :AND val eq foo bar"     # val eq foo bar
-   "val eq foo baz :OR key !~ /pattern/i"
+     "key =~ /pattern/i :AND val =~ /pattern/i"
+     "key =~ /pattern/i :AND val eq foo bar"     # val eq "foo bar"
+     "val eq foo baz :OR key !~ /pattern/i"
 
-      key means to match against keys in the hash
-      likewise, val means to match against values
+     * key matches on keys in the hash
+     * val matches on values
 
-   :AND(s) and :OR(s) mixed together is not supported
+=over 3
+
+=item * The modifiers C<:AND> and C<:OR> may be mixed case. e.g. C<:And>
+
+=item * Mixing C<:AND> and C<:OR> in the query is not supported.
+
+=back
 
 =head1 API DOCUMENTATION
 
-To be completed before the final 1.700 release.
+This module may involve TIE when accessing the object via hash-like behavior.
+Only shared instances are impacted if doing so. Although likely fast enough for
+many use cases, use the OO interface if better performance is desired.
 
 =over 3
 
@@ -438,75 +429,195 @@ Constructs a new object, with an optional list of key-value pairs.
 
 =item clear
 
+Removes all key-value pairs from the hash.
+
+   $ha->clear;
+   %{$ha} = ();
+
 =item clone ( key [, key, ... ] )
 
-=item clone
+Creates a shallow copy, a C<MCE::Shared::Hash> object. It returns an exact
+copy if no arguments are given. Otherwise, the object includes only the given
+keys. Keys that do not exist in the hash will have the C<undef> value.
+
+   $ha2 = $ha->clone( "key1", "key2" );
+   $ha2 = $ha->clone;
 
 =item delete ( key )
 
+Deletes and returns the value by given key or C<undef> if the key does not
+exists in the hash.
+
+   $val = $ha->delete( "some key" );
+   $val = delete $ha->{ "some key" };
+
 =item del
 
 C<del> is an alias for C<delete>.
 
 =item exists ( key )
 
-=item flush ( key [, key, ... ] )
+Determines if a key exists in the hash.
 
-=item flush
+   if ( $ha->exists( "some key" ) ) { ... }
+   if ( exists $ha->{ "some key" } ) { ... }
+
+=item flush ( key [, key, ... ] )
 
 Same as C<clone>. Though, clears all existing items before returning.
 
 =item get ( key )
 
+Gets the value of a hash key or C<undef> if the key does not exists.
+
+   $val = $ha->get( "some key" );
+   $val = $ha->{ "some key" };
+
 =item iterator ( key [, key, ... ] )
 
+Returns a code reference for iterating a list of key-value pairs stored in
+the hash when no arguments are given. Otherwise, returns a code reference for
+iterating the given keys in the same order. Keys that do not exist will have
+the C<undef> value.
+
+The list of keys to return is set when the closure is constructed. Later keys
+added to the hash are not included. Subsequently, the C<undef> value is
+returned for deleted keys.
+
+   $iter = $ha->iterator;
+   $iter = $ha->iterator( "key1", "key2" );
+
+   while ( my ( $key, $val ) = $iter->() ) {
+      ...
+   }
+
 =item iterator ( "query string" )
 
-=item iterator
+Returns a code reference for iterating a list of key-value pairs that match
+the given criteria. It returns an empty list if the search found nothing.
+The syntax for the C<query string> is described above.
+
+   $iter = $ha->iterator( "val eq some value" );
+   $iter = $ha->iterator( "key eq some key :AND val =~ /sun|moon|air|wind/" );
+   $iter = $ha->iterator( "val eq sun :OR val eq moon :OR val eq foo" );
+   $iter = $ha->iterator( "key =~ /$pattern/" );
+
+   while ( my ( $key, $val ) = $iter->() ) {
+      ...
+   }
 
 =item keys ( key [, key, ... ] )
 
+Returns all keys in the hash when no arguments are given. Otherwise, returns
+the given keys in the same order. Keys that do not exist will have the C<undef>
+value. In scalar context, returns the size of the hash.
+
+   @keys = $ha->keys;
+   @keys = $ha->keys( "key1", "key2" );
+   $len  = $ha->keys;
+
 =item keys ( "query string" )
 
-=item keys
+Returns only keys that match the given criteria. It returns an empty list
+if the search found nothing. The syntax for the C<query string> is described
+above. In scalar context, returns the size of the resulting list.
+
+   @keys = $ha->keys( "val eq some value" );
+   @keys = $ha->keys( "key eq some key :AND val =~ /sun|moon|air|wind/" );
+   @keys = $ha->keys( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len  = $ha->keys( "key =~ /$pattern/" );
 
 =item len ( key )
 
-Returns the length of the value stored at key.
+Returns the size of the hash when no arguments are given. For the given key,
+returns the length of the value stored at key or the C<undef> value if the
+key does not exists.
 
-   $len = $ha->len( $key );
-
-=item len
-
-Returns the number of keys stored in the hash.
-
-   $len = $ha->len;
+   $size = $ha->len;
+   $len  = $ha->len( "key1" );
+   $len  = length $ha->{ "key1" };
 
 =item mdel ( key [, key, ... ] )
 
+Deletes one or more keys in the hash and returns the number of keys deleted.
+A given key which does not exist in the hash is not counted.
+
+   $cnt = $ha->mdel( "key1", "key2" );
+
 =item mexists ( key [, key, ... ] )
 
+Returns a true value if all given keys exists in the hash. A false value is
+returned otherwise.
+
+   if ( $ha->mexists( "key1", "key2" ) ) { ... }
+
 =item mget ( key [, key, ... ] )
 
+Gets the values of all given keys. It returns C<undef> for keys which do not
+exists in the hash.
+
+   ( $val1, $val2 ) = $ha->mget( "key1", "key2" );
+
 =item mset ( key, value [, key, value, ... ] )
 
+Sets multiple key-value pairs in a hash and returns the number of keys stored
+in the hash.
+
+   $len = $ha->mset( "key1" => "val1", "key2" => "val2" );
+
 =item merge
 
 C<merge> is an alias for C<mset>.
 
-=item pairs ( key [, key, ... ] )
-
 =item pairs ( "query string" )
 
-=item pairs
+Returns key-value pairs in the hash when no arguments are given. Otherwise,
+returns key-value pairs for the given keys in the same order. Keys that do not
+exist will have the C<undef> value. In scalar context, returns the size of the
+hash.
+
+   @pairs = $ha->pairs;
+   @pairs = $ha->pairs( "key1", "key2" );
+   $len   = $ha->pairs;
+
+=item pairs ( key [, key, ... ] )
+
+Returns only key-value pairs that match the given criteria. It returns an
+empty list if the search found nothing. The syntax for the C<query string> is
+described above. In scalar context, returns the size of the resulting list.
+
+   @pairs = $ha->pairs( "val eq some value" );
+   @pairs = $ha->pairs( "key eq some key :AND val =~ /sun|moon|air|wind/" );
+   @pairs = $ha->pairs( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len   = $ha->pairs( "key =~ /$pattern/" );
 
 =item set ( key, value )
 
+Sets the value of the given hash key and returns its new value.
+
+   $val = $ha->set( "key", "value" );
+   $val = $ha->{ "key" } = "value";
+
 =item values ( key [, key, ... ] )
 
+Returns all values in the hash when no arguments are given. Otherwise, returns
+values for the given keys in the same order. Keys that do not exist will have
+the C<undef> value. In scalar context, returns the size of the hash.
+
+   @vals = $ha->values;
+   @vals = $ha->values( "key1", "key2" );
+   $len  = $ha->values;
+
 =item values ( "query string" )
 
-=item values
+Returns only values that match the given criteria. It returns an empty list
+if the search found nothing. The syntax for the C<query string> is described
+above. In scalar context, returns the size of the resulting list.
+
+   @vals = $ha->values( "val eq some value" );
+   @vals = $ha->values( "key eq some key :AND val =~ /sun|moon|air|wind/" );
+   @vals = $ha->values( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len  = $ha->values( "key =~ /$pattern/" );
 
 =item vals
 
@@ -526,7 +637,7 @@ L<http://redis.io/commands#strings> with key representing the hash key.
 
 Appends a value to a key and returns its new length.
 
-   $len = $ha->append( $key, 'foo' );
+   $len = $ha->append( $key, "foo" );
 
 =item decr ( key )
 
@@ -556,7 +667,7 @@ Increments the value of a key by one and returns its old value.
 
 Sets the value of a key and returns its old value.
 
-   $old = $ha->getset( $key, 'baz' );
+   $old = $ha->getset( $key, "baz" );
 
 =item incr ( key )
 
@@ -574,11 +685,11 @@ Increments the value of a key by the given number and returns its new value.
 
 =head1 CREDITS
 
-The implementation is inspired by L<Tie::StdHash|Tie::StdHash>.
+The implementation is inspired by L<Tie::StdHash>.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
