@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
@@ -24,8 +24,6 @@ use overload (
    fallback => 1
 );
 
-no overloading;
-
 # Based on Tie::StdScalar from Tie::Scalar.
 
 sub TIESCALAR {
@@ -45,8 +43,7 @@ sub FETCH { ${ $_[0] } }
 # append ( string )
 
 sub append {
-   ${ $_[0] } .= $_[1] || '';
-   length ${ $_[0] };
+   length( ${ $_[0] } .= $_[1] // '' );
 }
 
 # decr
@@ -60,16 +57,23 @@ sub decr    { --${ $_[0] }               }
 sub decrby  {   ${ $_[0] } -= $_[1] || 0 }
 sub incr    { ++${ $_[0] }               }
 sub incrby  {   ${ $_[0] } += $_[1] || 0 }
-sub getdecr {   ${ $_[0] }--        || 0 }
-sub getincr {   ${ $_[0] }++        || 0 }
+sub getdecr {   ${ $_[0] }--        // 0 }
+sub getincr {   ${ $_[0] }++        // 0 }
 
 # getset ( value )
 
-sub getset { my $old = ${ $_[0] }; ${ $_[0] } = $_[1]; $old }
+sub getset {
+   my $old = ${ $_[0] };
+   ${ $_[0] } = $_[1];
+
+   $old;
+}
 
 # len ( )
 
-sub len { length ${ $_[0] } || 0 }
+sub len {
+   length ${ $_[0] };
+}
 
 {
    no strict 'refs';
@@ -95,7 +99,7 @@ MCE::Shared::Scalar - Scalar helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Scalar version 1.699_010
+This document describes MCE::Shared::Scalar version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -126,10 +130,14 @@ This document describes MCE::Shared::Scalar version 1.699_010
 
 =head1 DESCRIPTION
 
-Helper class for L<MCE::Shared|MCE::Shared>.
+Helper class for L<MCE::Shared>.
 
 =head1 API DOCUMENTATION
 
+This module may involve TIE when accessing the object via scalar dereferencing.
+Only shared instances are impacted if doing so. Although likely fast enough for
+many use cases, use the OO interface if better performance is desired.
+
 =over 3
 
 =item new ( [ value ] )
@@ -139,13 +147,13 @@ Constructs a new object. Its value is undefined when C<value> is not specified.
    # non-shared
    use MCE::Shared::Scalar;
 
-   $var = MCE::Shared::Scalar->new( 'foo' );
+   $var = MCE::Shared::Scalar->new( "foo" );
    $var = MCE::Shared::Scalar->new;
 
    # shared
    use MCE::Shared;
 
-   $var = MCE::Shared->scalar( 'bar' );
+   $var = MCE::Shared->scalar( "bar" );
    $var = MCE::Shared->scalar;
 
 =item set ( value )
@@ -153,9 +161,9 @@ Constructs a new object. Its value is undefined when C<value> is not specified.
 Preferably, set the value via the OO interface. Otherwise, C<TIE> is activated
 on-demand for setting the value. The new value is returned in scalar context.
 
-   $val = $var->set( 'baz' );
-   $var->set( 'baz' );
-   $$var = 'baz';
+   $val = $var->set( "baz" );
+   $var->set( "baz" );
+   ${$var} = "baz";
 
 =item get
 
@@ -163,13 +171,15 @@ Likewise, obtain the value via the OO interface. C<TIE> is utilized for
 retrieving the value otherwise.
 
    $val = $var->get;
-   $val = $$var;
+   $val = ${$var};
 
 =item len
 
-Returns the length of the value.
+Returns the length of the value. It returns the C<undef> value if the value
+is not defined.
 
    $len = $var->len;
+   length ${$var};
 
 =back
 
@@ -185,7 +195,7 @@ L<http://redis.io/commands#strings> without the key argument.
 
 Appends a value at the end of the current value and returns its new length.
 
-   $len = $var->append( 'foo' );
+   $len = $var->append( "foo" );
 
 =item decr
 
@@ -215,7 +225,7 @@ Increments the value by one and returns its old value.
 
 Sets the value and returns its old value.
 
-   $old = $var->getset( 'baz' );
+   $old = $var->getset( "baz" );
 
 =item incr
 
@@ -233,11 +243,11 @@ Increments the value by the given number and returns its new value.
 
 =head1 CREDITS
 
-The implementation is inspired by L<Tie::StdScalar|Tie::StdScalar>.
+The implementation is inspired by L<Tie::StdScalar>.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
