@@ -12,7 +12,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric once );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -510,7 +510,7 @@ sub _loop {
 
             $_itr{ $_id } = sub {
                my $_key = shift @_keys;
-               if (!defined $_key) {
+               if ( !defined $_key ) {
                   print {$_DAU_R_SOCK} '-1'.$LF;
                   return;
                }
@@ -526,10 +526,10 @@ sub _loop {
             my @_a = @{ $_itr{ "$_id:args" } };
             my $_data; my $_ta = 0;
 
-            if ($_a[0] =~ /^:lists$/i) {
+            if ( $_a[0] =~ /^:lists$/i ) {
                $_data = $_obj{ $_id }->[1][0];
                shift @_a;
-               if (!scalar @_a) {
+               if ( ! @_a ) {
                   @_a = $_obj{ $_id }->lkeys();
                }
                elsif ( @_a == 1 && $_a[0] =~ /^(?:key|\S+)[ ]+\S\S?[ ]+\S/ ) {
@@ -542,8 +542,8 @@ sub _loop {
             }
             else {
                $_data = $_obj{ $_id }->[0][0];
-               shift @_a if ($_a[0] =~ /^:hashes$/i);
-               if (!scalar @_a) {
+               shift @_a if ( $_a[0] =~ /^:hashes$/i );
+               if ( ! @_a ) {
                   @_a = $_obj{ $_id }->hkeys();
                }
                elsif ( @_a == 1 && $_a[0] =~ /^(?:key|\S+)[ ]+\S\S?[ ]+\S/ ) {
@@ -557,7 +557,7 @@ sub _loop {
 
             $_itr{ $_id } = sub {
                my $_key = shift @_a;
-               if (!defined $_key) {
+               if ( !defined $_key ) {
                   print {$_DAU_R_SOCK} '-1'.$LF;
                   return;
                }
@@ -917,7 +917,7 @@ sub _loop {
          }
          else {
             weaken( delete $_itr{ $_id } ) if ( exists $_itr{ $_id } );
-            if (scalar @_args) {
+            if ( @_args ) {
                $_itr{ "$_id:args" } = \@_args;
             } else {
                delete $_itr{ "$_id:args" };
@@ -1365,15 +1365,17 @@ use Scalar::Util qw( looks_like_number );
 use MCE::Shared::Base;
 use bytes;
 
-my %_hash_supported = (qw/
-   MCE::Shared::Hash 1 MCE::Shared::Ordhash 1 Hash::Ordered 1
-/);
-
 use constant {
    _UNDEF => 0, _ARRAY => 1, _SCALAR => 2,  # wantarray
    _CLASS => 1, _DREF  => 2, _ITER   => 3,  # shared object
 };
 
+my %_hash_support = (qw/
+   MCE::Shared::Hash     1
+   MCE::Shared::Ordhash  1
+   Hash::Ordered         1
+/);
+
 use overload (
    q("")    => \&MCE::Shared::Base::_stringify,
    q(0+)    => \&MCE::Shared::Base::_numify,
@@ -1381,23 +1383,21 @@ use overload (
       no overloading;
       $_[0]->[_DREF] || do {
          return $_[0] if $_[0]->[_CLASS] ne 'MCE::Shared::Array';
-         tie my @a, 'MCE::Shared::Object', bless([ $_[0]->[0] ], __PACKAGE__);
+         tie my @a, __PACKAGE__, bless([ $_[0]->[0] ], __PACKAGE__);
          $_[0]->[_DREF] = \@a;
       };
    },
    q(%{})   => sub {
-      no overloading;
       $_[0]->[_DREF] || do {
-         return $_[0] if !exists $_hash_supported{ $_[0]->[_CLASS] };
-         tie my %h, 'MCE::Shared::Object', bless([ $_[0]->[0] ], __PACKAGE__);
+         return $_[0] if !exists $_hash_support{ $_[0]->[_CLASS] };
+         tie my %h, __PACKAGE__, bless([ $_[0]->[0] ], __PACKAGE__);
          $_[0]->[_DREF] = \%h;
       };
    },
    q(${})   => sub {
-      no overloading;
       $_[0]->[_DREF] || do {
          return $_[0] if $_[0]->[_CLASS] ne 'MCE::Shared::Scalar';
-         tie my $s, 'MCE::Shared::Object', bless([ $_[0]->[0] ], __PACKAGE__);
+         tie my $s, __PACKAGE__, bless([ $_[0]->[0] ], __PACKAGE__);
          $_[0]->[_DREF] = \$s;
       };
    },
@@ -1497,8 +1497,7 @@ sub _init {
 ##
 ###############################################################################
 
-# Called by AUTOLOAD, STORE, hget/lget, len/hlen/llen, set/hset/lset,
-# decr/incr, lpush/rpush, and enqueue/enqueuep.
+# Called by AUTOLOAD, enqueue, enqueuep, STORE, set, decr, incr, and len.
 
 sub _auto {
    my ( $_fn, $_id, $_wa, $_len, $_buf ) = ( shift, shift()->[0] );
@@ -1796,7 +1795,7 @@ sub iterator {
       $ref =~ /^MCE::Shared::(?:Array|Hash|Ordhash)$/ ||
       $ref eq 'Hash::Ordered'
    ) {
-      if ( !scalar @keys ) {
+      if ( ! @keys ) {
          @keys = $self->keys;
       }
       elsif ( @keys == 1 && $keys[0] =~ /^(?:key|val)[ ]+\S\S?[ ]+\S/ ) {
@@ -1804,7 +1803,7 @@ sub iterator {
       }
       return sub {
          return unless @keys;
-         my $key = shift(@keys);
+         my $key = shift @keys;
          return ( $key => $self->get($key) );
       };
    }
@@ -1813,7 +1812,7 @@ sub iterator {
    elsif ( $ref eq 'MCE::Shared::Minidb' ) {
       if ( $keys[0] =~ /^:lists$/i ) {
          shift @keys;
-         if ( !scalar @keys ) {
+         if ( ! @keys ) {
             @keys = $self->lkeys;
          }
          elsif ( @keys == 1 && $keys[0] =~ /^(?:key|\S+)[ ]+\S\S?[ ]+\S/ ) {
@@ -1835,7 +1834,7 @@ sub iterator {
       }
       else {
          shift @keys if ( $keys[0] =~ /^:hashes$/i );
-         if ( !scalar @keys ) {
+         if ( ! @keys ) {
             @keys = $self->hkeys;
          }
          elsif ( @keys == 1 && $keys[0] =~ /^(?:key|\S+)[ ]+\S\S?[ ]+\S/ ) {
@@ -2227,8 +2226,8 @@ sub pending  { _req5('pending',  @_) }
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## Methods optimized for MCE::Shared::{ Array, Hash, Minidb, Ordhash, Scalar },
-## Hash::Ordered, and PDL.
+## Methods optimized for
+##  PDL, MCE::Shared::{ Array, Hash, Ordhash, Scalar }, and Hash::Ordered.
 ##
 ###############################################################################
 
@@ -2301,24 +2300,12 @@ sub set {
 }
 
 sub FETCH { _req6('FETCH', @_) }
+sub get   { _req6('get'  , @_) }
 sub CLEAR { _req7('CLEAR', @_) }
 sub clear { _req7('clear', @_) }
 sub decr  { _auto('decr' , @_) }
 sub incr  { _auto('incr' , @_) }
-
-sub hset  { _auto('hset' , @_) }
-sub lset  { _auto('lset' , @_) }
-
-sub  get  { _req6( 'get' , @_) }
-sub hget  { _auto('hget' , @_) }
-sub lget  { _auto('lget' , @_) }
-
-sub  len  { _auto( 'len' , @_) }
-sub hlen  { _auto('hlen' , @_) }
-sub llen  { _auto('llen' , @_) }
-
-sub lpush { _auto('lpush', @_) }
-sub rpush { _auto('rpush', @_) }
+sub len   { _auto('len'  , @_) }
 
 {
    no strict 'refs';
@@ -2342,15 +2329,15 @@ MCE::Shared::Server - Server/Object packages for MCE::Shared
 
 =head1 VERSION
 
-This document describes MCE::Shared::Server version 1.699_010
+This document describes MCE::Shared::Server version 1.699_011
 
 =head1 DESCRIPTION
 
-Core class for L<MCE::Shared|MCE::Shared>. See documentation there.
+Core class for L<MCE::Shared>. See documentation there.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
