@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.699_010';
+our $VERSION = '1.699_011';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
@@ -428,7 +428,7 @@ MCE::Util - Utility functions
 
 =head1 VERSION
 
-This document describes MCE::Util version 1.699_010
+This document describes MCE::Util version 1.699_011
 
 =head1 SYNOPSIS
 
@@ -482,11 +482,11 @@ In summary:
 =head1 ACKNOWLEDGEMENTS
 
 The portable code for detecting the number of processors was adopted from
-L<Test::Smoke::SysInfo|Test::Smoke::SysInfo>.
+L<Test::Smoke::SysInfo>.
 
 =head1 INDEX
 
-L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
+L<MCE|MCE>, L<MCE::Core>, L<MCE::Shared>
 
 =head1 AUTHOR
 
